@@ -8,9 +8,9 @@ my $ATTR_RE   = qr/
   \[
   ((?:$ESCAPE_RE|[\w\-])+)           # Key
   (?:
-    (\W)?                            # Operator
-    =
-    (?:"((?:\\"|[^"])*)"|([^\]]+))   # Value
+    (\W)?=                           # Operator
+    (?:"((?:\\"|[^"])*)"|([^\]]+?))  # Value
+    (?:\s+(i))?                      # Case-sensitivity
   )?
   \]
 /x;
@@ -41,14 +41,13 @@ sub _ancestor {
 }
 
 sub _attr {
-  my ($key, $regex, $current) = @_;
+  my ($name_re, $value_re, $current) = @_;
 
-  # Ignore namespace prefix
   my $attrs = $current->[2];
   for my $name (keys %$attrs) {
-    next unless $name =~ /(?:^|:)\Q$key\E$/;
-    return 1 unless defined $attrs->{$name} && defined $regex;
-    return 1 if $attrs->{$name} =~ $regex;
+    next unless $name =~ $name_re;
+    return 1 unless defined $attrs->{$name} && defined $value_re;
+    return 1 if $attrs->{$name} =~ $value_re;
   }
 
   return undef;
@@ -83,7 +82,7 @@ sub _compile {
   my $pattern = [[]];
   while ($css =~ /$TOKEN_RE/go) {
     my ($separator, $element, $pc, $attrs, $combinator)
-      = ($1, $2 // '', $3, $6, $11);
+      = ($1, $2 // '', $3, $6, $12);
 
     next unless $separator || $element || $pc || $attrs || $combinator;
 
@@ -96,21 +95,21 @@ sub _compile {
 
     # Tag
     push @$part, my $selector = [];
-    push @$selector, ['tag', qr/(?:^|:)\Q@{[_unescape($1)]}\E$/]
+    push @$selector, ['tag', _name($1)]
       if $element =~ s/^((?:\\\.|\\\#|[^.#])+)// && $1 ne '*';
 
     # Class or ID
     while ($element =~ /(?:([.#])((?:\\[.\#]|[^\#.])+))/g) {
       my ($name, $op) = $1 eq '.' ? ('class', '~') : ('id', '');
-      push @$selector, ['attr', $name, _regex($op, $2)];
+      push @$selector, ['attr', _name($name), _value($op, $2)];
     }
 
     # Pseudo classes (":not" contains more selectors)
-    push @$selector, ['pc', "$1", $1 eq 'not' ? _compile($2) : _equation($2)]
+    push @$selector, ['pc', lc $1, $1 eq 'not' ? _compile($2) : _equation($2)]
       while $pc =~ /$PSEUDO_CLASS_RE/go;
 
     # Attributes
-    push @$selector, ['attr', _unescape($1), _regex($2 // '', $3 // $4)]
+    push @$selector, ['attr', _name($1), _value($2 // '', $3 // $4, $5)]
       while $attrs =~ /$ATTR_RE/go;
 
     # Combinator
@@ -126,10 +125,10 @@ sub _equation {
   return [] unless my $equation = shift;
 
   # "even"
-  return [2, 2] if $equation =~ /^even$/i;
+  return [2, 2] if $equation =~ /^\s*even\s*$/i;
 
   # "odd"
-  return [2, 1] if $equation =~ /^odd$/i;
+  return [2, 1] if $equation =~ /^\s*odd\s*$/i;
 
   # Equation
   my $num = [1, 1];
@@ -147,6 +146,8 @@ sub _match {
   return undef;
 }
 
+sub _name {qr/(?:^|:)\Q@{[_unescape(shift)]}\E$/}
+
 sub _parent {
   my ($selectors, $current, $tree, $pos) = @_;
   return undef unless my $parent = $current->[3];
@@ -199,27 +200,6 @@ sub _pc {
   return undef;
 }
 
-sub _regex {
-  my ($op, $value) = @_;
-  return undef unless defined $value;
-  $value = quotemeta _unescape($value);
-
-  # "~=" (word)
-  return qr/(?:^|.*\s+)$value(?:\s+.*|$)/ if $op eq '~';
-
-  # "*=" (contains)
-  return qr/$value/ if $op eq '*';
-
-  # "^=" (begins with)
-  return qr/^$value/ if $op eq '^';
-
-  # "$=" (ends with)
-  return qr/$value$/ if $op eq '$';
-
-  # Everything else
-  return qr/^$value$/;
-}
-
 sub _select {
   my ($one, $tree, $pattern) = @_;
 
@@ -242,16 +222,14 @@ sub _selector {
   for my $s (@$selector) {
     my $type = $s->[0];
 
-    # Tag (ignore namespace prefix)
+    # Tag
     if ($type eq 'tag') { return undef unless $current->[1] =~ $s->[1] }
 
     # Attribute
     elsif ($type eq 'attr') { return undef unless _attr(@$s[1, 2], $current) }
 
     # Pseudo class
-    elsif ($type eq 'pc') {
-      return undef unless _pc(lc $s->[1], $s->[2], $current);
-    }
+    elsif ($type eq 'pc') { return undef unless _pc(@$s[1, 2], $current) }
   }
 
   return 1;
@@ -300,6 +278,27 @@ sub _unescape {
   return $value;
 }
 
+sub _value {
+  my ($op, $value, $insensitive) = @_;
+  return undef unless defined $value;
+  $value = ($insensitive ? '(?i)' : '') . quotemeta _unescape($value);
+
+  # "~=" (word)
+  return qr/(?:^|\s+)$value(?:\s+|$)/ if $op eq '~';
+
+  # "*=" (contains)
+  return qr/$value/ if $op eq '*';
+
+  # "^=" (begins with)
+  return qr/^$value/ if $op eq '^';
+
+  # "$=" (ends with)
+  return qr/$value$/ if $op eq '$';
+
+  # Everything else
+  return qr/^$value$/;
+}
+
 1;
 
 =encoding utf8
@@ -347,34 +346,53 @@ An C<E> element with a C<foo> attribute.
 
 An C<E> element whose C<foo> attribute value is exactly equal to C<bar>.
 
-  my $fields = $css->select('input[name="foo"]');
+  my $case_sensitive = $css->select('input[type="hidden"]');
+  my $case_sensitive = $css->select('input[type=hidden]');
+
+=head2 E[foo="bar" i]
+
+An C<E> element whose C<foo> attribute value is exactly equal to any
+(ASCII-range) case-permutation of C<bar>. Note that this selector is
+EXPERIMENTAL and might change without warning!
+
+  my $case_insensitive = $css->select('input[type="hidden" i]');
+  my $case_insensitive = $css->select('input[type=hidden i]');
+  my $case_insensitive = $css->select('input[class~="foo" i]');
+
+This selector is part of
+L<Selectors Level 4|http://dev.w3.org/csswg/selectors-4>, which is still a
+work in progress.
 
 =head2 E[foo~="bar"]
 
 An C<E> element whose C<foo> attribute value is a list of
 whitespace-separated values, one of which is exactly equal to C<bar>.
 
-  my $fields = $css->select('input[name~="foo"]');
+  my $foo = $css->select('input[class~="foo"]');
+  my $foo = $css->select('input[class~=foo]');
 
 =head2 E[foo^="bar"]
 
 An C<E> element whose C<foo> attribute value begins exactly with the string
 C<bar>.
 
-  my $fields = $css->select('input[name^="f"]');
+  my $begins_with = $css->select('input[name^="f"]');
+  my $begins_with = $css->select('input[name^=f]');
 
 =head2 E[foo$="bar"]
 
 An C<E> element whose C<foo> attribute value ends exactly with the string
 C<bar>.
 
-  my $fields = $css->select('input[name$="o"]');
+  my $ends_with = $css->select('input[name$="o"]');
+  my $ends_with = $css->select('input[name$=o]');
 
 =head2 E[foo*="bar"]
 
 An C<E> element whose C<foo> attribute value contains the substring C<bar>.
 
-  my $fields = $css->select('input[name*="fo"]');
+  my $contains = $css->select('input[name*="fo"]');
+  my $contains = $css->select('input[name*=fo]');
 
 =head2 E:root
 
