@@ -32,8 +32,7 @@ has reactor => sub { Mojo::IOLoop->singleton->reactor };
 sub DESTROY { shift->_cleanup }
 
 sub connect {
-  my $self = shift;
-  my $args = ref $_[0] ? $_[0] : {@_};
+  my ($self, $args) = (shift, ref $_[0] ? $_[0] : {@_});
 
   # Timeout
   weaken $self;
