@@ -129,6 +129,8 @@ sub parse {
   my $end     = $self->tag_end;
   my $start   = $self->line_start;
 
+  my $line_re
+    = qr/^(\s*)\Q$start\E(?:(\Q$replace\E)|(\Q$cmnt\E)|(\Q$expr\E))?(.*)$/;
   my $token_re = qr/
     (
       \Q$tag\E(?:\Q$replace\E|\Q$cmnt\E)                   # Replace
@@ -140,7 +142,7 @@ sub parse {
       (?:(?<!\w)\Q$cpst\E\s*)?(?:\Q$trim\E)?\Q$end\E       # End
     )
   /x;
-  my $cpen_re = qr/^(\Q$tag\E)(?:\Q$expr\E)?(?:\Q$escp\E)?\s*\Q$cpen\E/;
+  my $cpen_re = qr/^\Q$tag\E(?:\Q$expr\E)?(?:\Q$escp\E)?\s*\Q$cpen\E(.*)$/;
   my $end_re  = qr/^(?:(\Q$cpst\E)\s*)?(\Q$trim\E)?\Q$end\E$/;
 
   # Split lines
@@ -149,15 +151,16 @@ sub parse {
   for my $line (split "\n", $template) {
 
     # Turn Perl line into mixed line
-    if ($op eq 'text' && $line !~ s/^(\s*)\Q$start$replace\E/$1$start/) {
-      if ($line =~ s/^(\s*)\Q$start\E(?:(\Q$cmnt\E)|(\Q$expr\E))?//) {
+    if ($op eq 'text' && $line =~ $line_re) {
 
-        # Comment
-        if ($2) { $line = "$tag$2 $trim$end" }
+      # Escaped start
+      if ($2) { $line = "$1$start$5" }
 
-        # Expression or code
-        else { $line = $3 ? "$1$tag$3$line $end" : "$tag$line $trim$end" }
-      }
+      # Comment
+      elsif ($3) { $line = "$tag$3 $trim$end" }
+
+      # Expression or code
+      else { $line = $4 ? "$1$tag$4$5 $end" : "$tag$5 $trim$end" }
     }
 
     # Escaped line ending
@@ -167,7 +170,7 @@ sub parse {
     for my $token (split $token_re, $line) {
 
       # Capture end
-      $capture = 1 if $token =~ s/$cpen_re/$1/;
+      ($token, $capture) = ("$tag$1", 1) if $token =~ $cpen_re;
 
       # End
       if ($op ne 'text' && $token =~ $end_re) {
@@ -184,16 +187,16 @@ sub parse {
       }
 
       # Code
-      elsif ($token =~ /^\Q$tag\E$/) { $op = 'code' }
+      elsif ($token eq $tag) { $op = 'code' }
 
       # Expression
-      elsif ($token =~ /^\Q$tag$expr\E$/) { $op = 'expr' }
+      elsif ($token eq "$tag$expr") { $op = 'expr' }
 
       # Expression that needs to be escaped
-      elsif ($token =~ /^\Q$tag$expr$escp\E$/) { $op = 'escp' }
+      elsif ($token eq "$tag$expr$escp") { $op = 'escp' }
 
       # Comment
-      elsif ($token =~ /^\Q$tag$cmnt\E$/) { $op = 'cmnt' }
+      elsif ($token eq "$tag$cmnt") { $op = 'cmnt' }
 
       # Text (comments are just ignored)
       elsif ($op ne 'cmnt') {
