@@ -60,8 +60,8 @@ our @EXPORT_OK = (
   qw(xml_escape xor_encode xss_escape)
 );
 
-sub b64_decode { decode_base64($_[0]) }
-sub b64_encode { encode_base64($_[0], $_[1]) }
+sub b64_decode { decode_base64 $_[0] }
+sub b64_encode { encode_base64 $_[0], $_[1] }
 
 sub camelize {
   my $str = shift;
@@ -80,7 +80,7 @@ sub class_to_file {
   return decamelize($class);
 }
 
-sub class_to_path { join '.', join('/', split /::|'/, shift), 'pm' }
+sub class_to_path { join '.', join('/', split(/::|'/, shift)), 'pm' }
 
 sub decamelize {
   my $str = shift;
@@ -101,7 +101,7 @@ sub decode {
 
 sub deprecated {
   local $Carp::CarpLevel = 1;
-  $ENV{MOJO_FATAL_DEPRECATIONS} ? croak(@_) : carp(@_);
+  $ENV{MOJO_FATAL_DEPRECATIONS} ? croak @_ : carp @_;
 }
 
 sub dumper {
@@ -110,7 +110,7 @@ sub dumper {
 
 sub encode { _encoding($_[0])->encode("$_[1]") }
 
-sub hmac_sha1_sum { hmac_sha1_hex(@_) }
+sub hmac_sha1_sum { hmac_sha1_hex @_ }
 
 sub html_unescape {
   my $str = shift;
@@ -118,8 +118,8 @@ sub html_unescape {
   return $str;
 }
 
-sub md5_bytes { md5(@_) }
-sub md5_sum   { md5_hex(@_) }
+sub md5_bytes { md5 @_ }
+sub md5_sum   { md5_hex @_ }
 
 sub monkey_patch {
   my ($class, %patch) = @_;
@@ -139,7 +139,7 @@ sub punycode_decode {
   my @output;
 
   # Consume all code points before the last delimiter
-  push @output, split '', $1 if $input =~ s/(.*)\x2d//s;
+  push @output, split('', $1) if $input =~ s/(.*)\x2d//s;
 
   while (length $input) {
     my $oldi = $i;
@@ -232,8 +232,8 @@ sub secure_compare {
   return $r == 0;
 }
 
-sub sha1_bytes { sha1(@_) }
-sub sha1_sum   { sha1_hex(@_) }
+sub sha1_bytes { sha1 @_ }
+sub sha1_sum   { sha1_hex @_ }
 
 sub slurp {
   my $path = shift;
@@ -471,7 +471,7 @@ Base64 encode bytes, the line ending defaults to a newline.
 
   my $camelcase = camelize $snakecase;
 
-Convert snake_case string to CamelCase and replace C<-> with C<::>.
+Convert C<snake_case> string to C<CamelCase> and replace C<-> with C<::>.
 
   # "FooBar"
   camelize 'foo_bar';
@@ -516,7 +516,7 @@ Convert class name to path.
 
   my $snakecase = decamelize $camelcase;
 
-Convert CamelCase string to snake_case and replace C<::> with C<->.
+Convert C<CamelCase> string to C<snake_case> and replace C<::> with C<->.
 
   # "foo_bar"
   decamelize 'FooBar';
